"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.lightTheme = void 0;

var _polished = require("polished");

var _breakpoint = require("./breakpoint");

var _spacing = require("./spacing");

var _breakpoints, _spacings;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var colorPrimary = "#4055A8";
var colorLight = "#FFFFFF";
var colorDark = "#000000";
var pageBackgroundColor = (0, _polished.setLightness)(0.95, colorPrimary);
var pageContentBackgroundColor = (0, _polished.setLightness)(0.97, colorPrimary);
var lightTheme = {
  // Color constants
  colorPrimary: colorPrimary,
  colorLight: colorLight,
  colorDark: colorDark,
  // Typography constants
  fontFamily: '-apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,Oxygen-Sans,Ubuntu,Cantarell,"Helvetica Neue",sans-serif',
  monoFontFamily: "'Fira Code', monospace",
  // Breakpoint constants
  breakpoints: (_breakpoints = {}, _defineProperty(_breakpoints, _breakpoint.Breakpoint.xs, 414), _defineProperty(_breakpoints, _breakpoint.Breakpoint.sm, 568), _defineProperty(_breakpoints, _breakpoint.Breakpoint.md, 768), _defineProperty(_breakpoints, _breakpoint.Breakpoint.lg, 896), _defineProperty(_breakpoints, _breakpoint.Breakpoint.xl, 1200), _breakpoints),
  // Spacing constants
  spacings: (_spacings = {}, _defineProperty(_spacings, _spacing.Spacing.xs, 3), _defineProperty(_spacings, _spacing.Spacing.sm, 6), _defineProperty(_spacings, _spacing.Spacing.md, 12), _defineProperty(_spacings, _spacing.Spacing.lg, 24), _defineProperty(_spacings, _spacing.Spacing.xl, 48), _spacings),
  // Button constants
  buttonPrimaryBackgroundColor: colorPrimary,
  buttonPrimaryShadow: "0 2px 4px ".concat((0, _polished.transparentize)(0.9, colorDark), ", 0px 2px 8px ").concat((0, _polished.transparentize)(0.8, colorDark), ", inset 0px 1px 1px ").concat((0, _polished.transparentize)(0.8, colorLight)),
  buttonPrimaryTextColor: colorLight,
  buttonPrimaryTextShadow: "0px 1px 2px ".concat((0, _polished.transparentize)(0.8, colorLight), ", 0px -1px 2px ").concat((0, _polished.transparentize)(0.8, colorDark)),
  buttonPrimaryBorderRadius: "3px",
  buttonVerticalPadding: _spacing.Spacing.md,
  buttonHorizontalPadding: _spacing.Spacing.lg,
  // Card constants
  cardBackgroundColor: colorLight,
  cardBorderRadius: "4px",
  cardShadow: "0 2px 2px ".concat((0, _polished.transparentize)(0.9, colorDark), ", 0 2px 4px ").concat((0, _polished.transparentize)(0.95, colorDark)),
  // Page constants
  pageBackgroundColor: pageBackgroundColor,
  pageContentBackgroundColor: pageContentBackgroundColor,
  pageContentHorizontalSpacing: _spacing.Spacing.md,
  // Input constants
  inputBackgroundColor: colorLight,
  inputBorderRadius: "3px",
  inputVerticalPadding: _spacing.Spacing.md,
  inputHorizontalPadding: _spacing.Spacing.lg,
  inputBorder: "none",
  inputShadow: "inset 0 1px 1px ".concat((0, _polished.transparentize)(0.9, colorDark)),
  // Focus shadow constants
  focusShadowColor: (0, _polished.transparentize)(0.8, colorPrimary),
  focusShadowSize: "5px",
  focusShadowTransitionDuration: "100ms",
  // Code block constants
  codeBlockSpacing: _spacing.Spacing.md
};
exports.lightTheme = lightTheme;